Welcome to intake_elasticsearch's documentation!
================================================

This package enables the Intake data access and catalog system to read from the ElasticSearch
data analytics platform.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart.rst
   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
